nltk.tbl package
================

Submodules
----------

.. toctree::
   :maxdepth: 4

   nltk.tbl.api
   nltk.tbl.demo
   nltk.tbl.erroranalysis
   nltk.tbl.feature
   nltk.tbl.rule
   nltk.tbl.template

Module contents
---------------

.. automodule:: nltk.tbl
   :members:
   :undoc-members:
   :show-inheritance:
